/*                                                                                                            
 * Copyright (c) 2001 EU DataGrid.                                                                             
 * For license conditions see http://www.eu-datagrid.org/license.html                                          
 *
 * Copyright (c) 2001, 2002 by 
 *     Martijn Steenbakkers <martijn@nikhef.nl>,
 *     David Groep <davidg@nikhef.nl>,
 *     NIKHEF Amsterdam, the Netherlands
 */

/*!
    \file   lcas_log.h
    \brief  Logging API for the LCAS plugins and LCAS itself
    \author Martijn Steenbakkers for the EU DataGrid.

    This header contains the declarations of the LCAS logging functions
    The LCAS plugins can use this API to write output to the LCAS logging
    devices.
    -# lcas_log(): Log to LCAS logging devices.
    -# lcas_log_debug(): Produce debugging output.
    \ingroup APIforLcasPlugins
*/

#ifndef LCAS_LOG_H
#define LCAS_LOG_H

/******************************************************************************
                             Include header files
******************************************************************************/
#include <syslog.h>

/******************************************************************************
 *                            Module definition
 *****************************************************************************/
/******************************************************************************
Function:       lcas_log()
Description:    Log information to file and or syslog
Parameters:
                prty:    syslog priority (if 0 don't syslog)
                fmt:     string format
Returns:        0 succes
                1 failure
******************************************************************************/
/*!
    \fn lcas_log(
        int prty,
        char * fmt,
        ...
        )
    \brief log information
    
    This function does the logging for the LCAS and its plugins.
    Syslog() is called with the specified priority. No syslog() is done if the
    priority is 0.

    \param prty syslog priority (if 0 don't syslog).
    \param fmt  string format
    \param ...  variable argument list

    \retval 0 succes.
    \retval 1 failure.
*/
extern int lcas_log(
        int prty,
        char * fmt,
        ...
);

/******************************************************************************
Function:       lcas_log_debug()
Description:    Print debugging information
Parameters:
                debug_lvl: debugging level
                fmt:       string format
Returns:        0 succes
                1 failure
******************************************************************************/
/*!
    \fn lcas_log_debug(
        int debug_lvl,
        char * fmt,
        ...
        )
    \brief Print debugging information

    This function prints debugging information (using lcas_log with priority 0)
    provided debug_lvl <= DEBUG_LEVEL (default is 0).

    \param debug_lvl debugging level
    \param fmt       string format
    \param ...       variable argument list

    \retval 0 succes.
    \retval 1 failure.
*/
extern int lcas_log_debug(
        int debug_lvl,
        char * fmt,
        ...
);

/******************************************************************************
Function:       lcas_log_time()
Description:    Log information to file and or syslog with a timestamp
Parameters:
                prty:    syslog priority (if 0 don't syslog)
                fmt:     string format
Returns:        0 succes
                1 failure
******************************************************************************/
extern int lcas_log_time(
        int prty, 
        char * fmt, 
        ...
);

/******************************************************************************
Function:       lcas_get_debug_level()
Description:    Retrieve the debug_level
Parameters:
Returns:        the debug_level
******************************************************************************/
extern int lcas_get_debug_level(
);

#endif /* LCAS_LOG_H */

/******************************************************************************
CVS Information:
    $Source: /local/reps/lcgware/fabric_mgt/gridification/lcas/include/lcas_log.h,v $
    $Date: 2003/08/22 16:12:29 $
    $Revision: 2.7 $
    $Author: martijn $
******************************************************************************/
